@@ -48,6 +48,7 @@ SELECT_SPEAKER_PROMPT_TEMPLATE = (
 @export_module("autogen")
 class GroupChat:
     """(In preview) A group chat class that contains the following data fields:
+
     - agents: a list of participating agents.
     - messages: a list of messages in the group chat.
     - max_round: the maximum number of rounds.
@@ -103,9 +104,9 @@ class GroupChat:
         Default is 2.
     - select_speaker_transform_messages: (optional) the message transformations to apply to the nested select speaker agent-to-agent chat messages.
         Takes a TransformMessages object, defaults to None and is only utilised when the speaker selection method is "auto".
-    - select_speaker_auto_verbose: whether to output the select speaker responses and selections
+    - select_speaker_auto_verbose: whether to output the select speaker responses and selections.
         If set to True, the outputs from the two agents in the nested select speaker chat will be output, along with
-        whether the responses were successful, or not, in selecting an agent
+        whether the responses were successful, or not, in selecting an agent.
         Applies only to "auto" speaker selection method.
     - allow_repeat_speaker: whether to allow the same speaker to speak consecutively.
         Default is True, in which case all speakers are allowed to speak consecutively.
@@ -174,6 +175,7 @@ class GroupChat:
     )
 
     allowed_speaker_transitions_dict: dict[str, list[Agent]] = field(init=False)
+    _inter_agent_guardrails: list = field(default_factory=list, init=False)
 
     def __post_init__(self):
         # Post init steers clears of the automatically generated __init__ method from dataclass
@@ -312,7 +314,8 @@ class GroupChat:
             message["name"] = speaker.name
         if not isinstance(message["content"], str) and not isinstance(message["content"], list):
             message["content"] = str(message["content"])
-        message["content"] = content_str(message["content"])
+        if not isinstance(message["content"], list):
+            message["content"] = content_str(message["content"])
         self.messages.append(message)
 
     def agent_by_name(self, name: str, recursive: bool = False, raise_on_name_conflict: bool = False) -> Agent | None:
@@ -1000,7 +1003,7 @@ class GroupChat:
             message_content = message_content["content"]
         message_content = content_str(message_content)
 
-        mentions = dict()
+        mentions = {}
         for agent in agents:
             # Finds agent mentions, taking word boundaries into account,
             # accommodates escaping underscores and underscores as spaces
@@ -1019,9 +1022,7 @@ class GroupChat:
         return mentions
 
     def _run_input_guardrails(
-        self,
-        agent: "ConversableAgent",
-        messages: list[dict[str, Any]] | None = None,
+        self, agent: "ConversableAgent", messages: list[dict[str, Any]] | None = None
     ) -> str | None:
         """Run input guardrails for an agent before the reply is generated.
 
@@ -1029,27 +1030,45 @@ class GroupChat:
             agent (ConversableAgent): The agent whose input guardrails to run.
             messages (Optional[list[dict[str, Any]]]): The messages to check against the guardrails.
         """
-        for guardrail in agent.input_guardrails:
-            guardrail_result = guardrail.check(context=messages)
-
-            if guardrail_result.activated:
-                guardrail.target.activate_target(self)
-                return f"{guardrail.activation_message}\nJustification: {guardrail_result.justification}"
+        if guardrail_result := agent.run_input_guardrails(messages):
+            guardrail_result.guardrail.target.activate_target(self)
+            return guardrail_result.reply
         return None
 
-    def _run_output_guardrails(self, agent: "ConversableAgent", reply: str) -> None:
+    def _run_output_guardrails(self, agent: "ConversableAgent", reply: str | dict[str, Any]) -> str | None:
         """Run output guardrails for an agent after the reply is generated.
 
         Args:
             agent (ConversableAgent): The agent whose output guardrails to run.
-            reply (str): The reply generated by the agent.
+            reply (str | dict[str, Any]): The reply generated by the agent.
         """
-        for guardrail in agent.output_guardrails:
-            guardrail_result = guardrail.check(context=reply)
+        if guardrail_result := agent.run_output_guardrails(reply):
+            guardrail_result.guardrail.target.activate_target(self)
+            return guardrail_result.reply
+        return None
 
-            if guardrail_result.activated:
-                guardrail.target.activate_target(self)
-                return f"{guardrail.activation_message}\nJustification: {guardrail_result.justification}"
+    def _run_inter_agent_guardrails(
+        self,
+        *,
+        src_agent_name: str,
+        dst_agent_name: str,
+        message_content: str,
+    ) -> str | None:
+        """Run policy-driven inter-agent guardrails, if any are configured.
+
+        Returns optional replacement content when a guardrail triggers.
+        """
+        guardrails = getattr(self, "_inter_agent_guardrails", None)
+        if not guardrails:
+            return None
+        for gr in guardrails:
+            reply = gr.check_and_act(
+                src_agent_name=src_agent_name,
+                dst_agent_name=dst_agent_name,
+                message_content=message_content,
+            )
+            if reply is not None:
+                return reply
         return None
 
 
@@ -1208,7 +1227,21 @@ class GroupChatManager(ConversableAgent):
             # broadcast the message to all agents except the speaker
             for agent in groupchat.agents:
                 if agent != speaker:
-                    self.send(message, agent, request_reply=False, silent=True)
+                    inter_reply = groupchat._run_inter_agent_guardrails(
+                        src_agent_name=speaker.name,
+                        dst_agent_name=agent.name,
+                        message_content=message,
+                    )
+                    if inter_reply is not None:
+                        replacement = (
+                            {"content": inter_reply, "name": speaker.name}
+                            if not isinstance(inter_reply, dict)
+                            else inter_reply
+                        )
+                        self.send(replacement, agent, request_reply=False, silent=True)
+                    else:
+                        self.send(message, agent, request_reply=False, silent=True)
+
             if self._is_termination_msg(message):
                 # The conversation is over
                 termination_reason = f"Termination message condition on the GroupChatManager '{self.name}' met"
@@ -1263,13 +1296,16 @@ class GroupChatManager(ConversableAgent):
                     reply = guardrails_reply
 
             # check for "clear history" phrase in reply and activate clear history function if found
-            if (
-                groupchat.enable_clear_history
-                and isinstance(reply, dict)
-                and reply["content"]
-                and "CLEAR HISTORY" in reply["content"].upper()
-            ):
-                reply["content"] = self.clear_agents_history(reply, groupchat)
+            if groupchat.enable_clear_history and isinstance(reply, dict) and reply.get("content"):
+                raw_content = reply.get("content")
+                normalized_content = (
+                    content_str(raw_content)
+                    if isinstance(raw_content, (str, list)) or raw_content is None
+                    else str(raw_content)
+                )
+                if "CLEAR HISTORY" in normalized_content.upper():
+                    reply["content"] = normalized_content
+                    reply["content"] = self.clear_agents_history(reply, groupchat)
 
             # The speaker sends the message without requesting a reply
             speaker.send(reply, self, request_reply=False, silent=silent)
@@ -1380,13 +1416,16 @@ class GroupChatManager(ConversableAgent):
                     reply = guardrails_reply
 
             # check for "clear history" phrase in reply and activate clear history function if found
-            if (
-                groupchat.enable_clear_history
-                and isinstance(reply, dict)
-                and reply["content"]
-                and "CLEAR HISTORY" in reply["content"].upper()
-            ):
-                reply["content"] = self.clear_agents_history(reply, groupchat)
+            if groupchat.enable_clear_history and isinstance(reply, dict) and reply.get("content"):
+                raw_content = reply.get("content")
+                normalized_content = (
+                    content_str(raw_content)
+                    if isinstance(raw_content, (str, list)) or raw_content is None
+                    else str(raw_content)
+                )
+                if "CLEAR HISTORY" in normalized_content.upper():
+                    reply["content"] = normalized_content
+                    reply["content"] = self.clear_agents_history(reply, groupchat)
 
             # The speaker sends the message without requesting a reply
             await speaker.a_send(reply, self, request_reply=False, silent=silent)
@@ -1661,7 +1700,13 @@ class GroupChatManager(ConversableAgent):
             _remove_termination_string = remove_termination_string
 
         if _remove_termination_string and messages[-1].get("content"):
-            messages[-1]["content"] = _remove_termination_string(messages[-1]["content"])
+            content_value = messages[-1]["content"]
+            if isinstance(content_value, str):
+                messages[-1]["content"] = _remove_termination_string(content_value)
+            elif isinstance(content_value, list):
+                messages[-1]["content"] = _remove_termination_string(content_str(content_value))
+            else:
+                messages[-1]["content"] = _remove_termination_string(str(content_value))
 
         # Check if the last message meets termination (if it has one)
         if self._is_termination_msg and self._is_termination_msg(last_message):
@@ -1707,23 +1752,32 @@ class GroupChatManager(ConversableAgent):
             agent._raise_exception_on_async_reply_functions()
 
     def clear_agents_history(self, reply: dict[str, Any], groupchat: GroupChat) -> str:
-        """Clears history of messages for all agents or selected one. Can preserve selected number of last messages.
-        That function is called when user manually provide "clear history" phrase in his reply.
-        When "clear history" is provided, the history of messages for all agents is cleared.
-        When "clear history `<agent_name>`" is provided, the history of messages for selected agent is cleared.
-        When "clear history `<nr_of_messages_to_preserve>`" is provided, the history of messages for all agents is cleared
-        except last `<nr_of_messages_to_preserve>` messages.
-        When "clear history `<agent_name>` `<nr_of_messages_to_preserve>`" is provided, the history of messages for selected
-        agent is cleared except last `<nr_of_messages_to_preserve>` messages.
-        Phrase "clear history" and optional arguments are cut out from the reply before it passed to the chat.
-
-        Args:
-            reply (dict): reply message dict to analyze.
-            groupchat (GroupChat): GroupChat object.
+        """Clears history of messages for all agents or a selected one. Can preserve a selected number of last messages.\n
+        \n
+        This function is called when the user manually provides the "clear history" phrase in their reply.\n
+        When "clear history" is provided, the history of messages for all agents is cleared.\n
+        When "clear history `<agent_name>`" is provided, the history of messages for the selected agent is cleared.\n
+        When "clear history `<nr_of_messages_to_preserve>`" is provided, the history of messages for all agents is cleared\n
+        except for the last `<nr_of_messages_to_preserve>` messages.\n
+        When "clear history `<agent_name>` `<nr_of_messages_to_preserve>`" is provided, the history of messages for the selected\n
+        agent is cleared except for the last `<nr_of_messages_to_preserve>` messages.\n
+        The phrase "clear history" and optional arguments are cut out from the reply before it is passed to the chat.\n
+        \n
+        Args:\n
+            reply (dict): reply message dict to analyze.\n
+            groupchat (GroupChat): GroupChat object.\n
         """
         iostream = IOStream.get_default()
 
-        reply_content = reply["content"]
+        raw_reply_content = reply.get("content")
+        if isinstance(raw_reply_content, str):
+            reply_content = raw_reply_content
+        elif isinstance(raw_reply_content, (list, type(None))):
+            reply_content = content_str(raw_reply_content)
+            reply["content"] = reply_content
+        else:
+            reply_content = str(raw_reply_content)
+            reply["content"] = reply_content
         # Split the reply into words
         words = reply_content.split()
         # Find the position of "clear" to determine where to start processing
