@@ -8,7 +8,14 @@ from ..cache.cache import Cache
 from .anthropic import AnthropicLLMConfigEntry
 from .bedrock import BedrockLLMConfigEntry
 from .cerebras import CerebrasLLMConfigEntry
-from .client import AzureOpenAILLMConfigEntry, DeepSeekLLMConfigEntry, OpenAILLMConfigEntry, OpenAIWrapper
+from .client import (
+    AzureOpenAILLMConfigEntry,
+    DeepSeekLLMConfigEntry,
+    OpenAILLMConfigEntry,
+    OpenAIResponsesLLMConfigEntry,
+    OpenAIV2LLMConfigEntry,
+    OpenAIWrapper,
+)
 from .cohere import CohereLLMConfigEntry
 from .gemini import GeminiLLMConfigEntry
 from .groq import GroqLLMConfigEntry
@@ -39,6 +46,8 @@ __all__ = [
     "MistralLLMConfigEntry",
     "OllamaLLMConfigEntry",
     "OpenAILLMConfigEntry",
+    "OpenAIResponsesLLMConfigEntry",
+    "OpenAIV2LLMConfigEntry",
     "OpenAIWrapper",
     "TogetherLLMConfigEntry",
     "config_list_from_dotenv",
