@@ -139,6 +139,8 @@ class GeminiLLMConfigEntry(LLMConfigEntry):
 class GeminiClient:
     """Client for Google's Gemini API."""
 
+    RESPONSE_USAGE_KEYS: list[str] = ["prompt_tokens", "completion_tokens", "total_tokens", "cost", "model"]
+
     # Mapping, where Key is a term used by Autogen, and Value is a term used by Gemini
     PARAMS_MAPPING = {
         "max_tokens": "max_output_tokens",
@@ -246,7 +248,7 @@ class GeminiClient:
 
         if model_name == "gemini-pro-vision":
             raise ValueError(
-                "Gemini 1.0 Pro vision ('gemini-pro-vision') has been deprecated, please consider switching to a different model, for example 'gemini-1.5-flash'."
+                "Gemini 1.0 Pro vision ('gemini-pro-vision') has been deprecated, please consider switching to a different model, for example 'gemini-2.5-flash'."
             )
         elif not model_name:
             raise ValueError(
@@ -385,9 +387,7 @@ class GeminiClient:
                             function={
                                 "name": fn_call.name,
                                 "arguments": (
-                                    json.dumps({key: val for key, val in fn_call.args.items()})
-                                    if fn_call.args is not None
-                                    else ""
+                                    json.dumps(dict(fn_call.args.items())) if fn_call.args is not None else ""
                                 ),
                             },
                             type="function",
@@ -857,10 +857,10 @@ class GeminiClient:
         """Convert safety settings to VertexAI format if needed,
         like when specifying them in the OAI_CONFIG_LIST
         """
-        if isinstance(safety_settings, list) and all([
+        if isinstance(safety_settings, list) and all(
             isinstance(safety_setting, dict) and not isinstance(safety_setting, VertexAISafetySetting)
             for safety_setting in safety_settings
-        ]):
+        ):
             vertexai_safety_settings = []
             for safety_setting in safety_settings:
                 if safety_setting["category"] not in VertexAIHarmCategory.__members__:
