@@ -13,4 +13,4 @@ __all__ = ["BaseModel"]
 
 
 class BaseModel(pydantic.BaseModel):
-    model_config = ConfigDict(extra="allow")
+    model_config = ConfigDict(extra="allow", defer_build=True)
