@@ -49,7 +49,7 @@ class WebSearchPreviewTool(Tool):
                 The default is `None`, which means the text will be returned as a string.
         """
         self.web_search_tool_param = WebSearchToolParam(
-            type="web_search_preview",
+            type="web_search_preview",  # type: ignore[typeddict-item]
             search_context_size=search_context_size,
             user_location=UserLocation(**user_location) if user_location else None,  # type: ignore[typeddict-item]
         )
